@@ -1197,7 +1197,7 @@ class MainWindow(QtG.QMainWindow):
             # self.fig.canvas.draw()
 
     def delete_box(self, box):
-        box.remove()
+        box.getRect().remove()
         del self.rectangles[self.rectangles.index(box)]
         self.fig.canvas.restore_region(self.background_current)
         self._draw_all_boxes()
